==> teavm-jso-apis-0.4.2-sources.jar: org/teavm/jso/core/JSFunction.java <==
/*
 *  Copyright 2014 Alexey Andreev.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.teavm.jso.core;

import org.teavm.jso.JSObject;
import org.teavm.jso.JSProperty;

/**
 *
 * @author Alexey Andreev
 */
public interface JSFunction extends JSObject {
    @JSProperty
    int getLength();

    @JSProperty
    String getName();

    JSObject call(JSObject thisArg);

    JSObject call(JSObject thisArg, JSObject a);

    JSObject call(JSObject thisArg, JSObject a, JSObject b);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c,
            JSObject d);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e, JSObject f);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e, JSObject f,
            JSObject g);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e, JSObject f,
            JSObject g, JSObject h);

    JSObject apply(JSObject thisArg, JSObject[] arguments);
}

==> teavm-jso-apis-0.6.0-sources.jar: org/teavm/jso/core/JSFunction.java <==
/*
 *  Copyright 2014 Alexey Andreev.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.teavm.jso.core;

import org.teavm.jso.JSByRef;
import org.teavm.jso.JSObject;
import org.teavm.jso.JSProperty;

public interface JSFunction extends JSObject {
    @JSProperty
    int getLength();

    @JSProperty
    String getName();

    JSObject call(JSObject thisArg);

    JSObject call(JSObject thisArg, JSObject a);

    JSObject call(JSObject thisArg, JSObject a, JSObject b);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c,
            JSObject d);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e, JSObject f);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e, JSObject f,
            JSObject g);

    JSObject call(JSObject thisArg, JSObject a, JSObject b, JSObject c, JSObject d, JSObject e, JSObject f,
            JSObject g, JSObject h);

    JSObject apply(JSObject thisArg, @JSByRef JSObject[] arguments);
}
